#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 either
version:              5.0.1.1
visibility:           public
id:                   either-5.0.1.1-LPXXSlC1FQ7DVSChfgPjER
key:                  either-5.0.1.1-LPXXSlC1FQ7DVSChfgPjER
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/either/
synopsis:             Combinators for working with sums
description:          Combinators for working with sums.
category:             Control, Monads
abi:                  1d23de30d658be6c3ce73b560f44064a
exposed:              True
exposed-modules:      Data.Either.Combinators Data.Either.Validation
import-dirs:          /usr/lib/ghc-8.10.5/site-local/either-5.0.1.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/either-5.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/either-5.0.1.1
hs-libraries:         HSeither-5.0.1.1-LPXXSlC1FQ7DVSChfgPjER
depends:
    base-4.14.2.0 bifunctors-5.5.11-5WHPU2oStxP1cNabXCzf9E mtl-2.2.2
    profunctors-5.6.2-68Okl6PP0cYKcJgfa1by0Q
    semigroupoids-5.3.5-CXCAmgAqO2AH1F4bh8bCjo

haddock-interfaces:   /usr/share/doc/haskell-either/html/either.haddock
haddock-html:         /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

